# Rozwiązanie zadania Wioska Logiki
# Zawody I stopnia XVII OIJ
# oij.edu.pl

# Bartosz Kostka

import enum
import re

class Rasa(enum.IntEnum):
    ORK = 0
    KRASNOLUD = 1
    ELF = 2
    
Pora = enum.Enum('Pora', ['DZIEN', 'NOC'])

# Każda wypowiedź składa się z trzech informacji:
#  - kto jest jej autorem
#  - o kim jest ta wypowiedź
#  - o jakiej rasie jest mowa.
class Wypowiedz:
  def __init__(self, autor_wypowiedzi, przedmiot_wypowiedzi, rasa):
    self.autor_wypowiedzi = autor_wypowiedzi
    self.przedmiot_wypowiedzi = przedmiot_wypowiedzi
    self.rasa = rasa 
  def __repr__(self):
    return "%s %s %s" % (self.autor_wypowiedzi, self.przedmiot_wypowiedzi, self.rasa)

mapa_imion = {}

def RasaZNapisu(napis_z_rasa):
  if napis_z_rasa == "orkiem": return Rasa.ORK
  if napis_z_rasa == "krasnoludem": return Rasa.KRASNOLUD
  if napis_z_rasa == "elfem": return Rasa.ELF

def NapisZMaski(maska):
  if maska == 1<<Rasa.ORK.value: return "orkiem"
  if maska == 1<<Rasa.KRASNOLUD.value: return "krasnoludem"
  if maska == 1<<Rasa.ELF.value: return "elfem"

# Zwraca maskę zawierającą wszystkie rasy poza tą w argumencie.
def InneRasy(rasa):
  wszystkie_rasy = (1<<len(Rasa))-1
  return wszystkie_rasy ^ (1<<rasa.value)

# Wyrażenia regularne zawierające dwa formaty wypowiedzi.
kWypowiedzOSamymSobie = re.compile("([A-Za-z]+): Jestem ([a-z]+).")
kWypowiedzOKimsInnym = re.compile("([A-Za-z]+): ([A-Za-z]+) jest ([a-z]+).")

# Parsuje wypowiedz w formacie tekstowym używając wyrażeń regularnych 
# i zwraca odpowiedni obiekt Wypowiedz.
def ParsujWypowiedz(wypowiedz):
  match = kWypowiedzOSamymSobie.fullmatch(wypowiedz)
  if match is not None:
    return Wypowiedz(mapa_imion[match.group(1)], mapa_imion[match.group(1)], 
                     RasaZNapisu(match.group(2)))
  match = kWypowiedzOKimsInnym.fullmatch(wypowiedz)
  if match is not None: 
    return Wypowiedz(mapa_imion[match.group(1)], mapa_imion[match.group(2)], 
                     RasaZNapisu(match.group(3)))

def ZliczZapaloneBity(x):
  if x == 0: return 0
  return (x%2) + ZliczZapaloneBity(x//2)

def main():
  (N, K) = tuple(map(int, input().split()))
  imiona = input().split()
  for i in range(N):
    mapa_imion[imiona[i]] = i
  
  wypowiedzi = []
  for i in range(K):
    wypowiedzi.append(ParsujWypowiedz(input()))
  
  mozliwe_scenariusze = []
  # Rozważamy wszystkie możliwości, czy mamy dzień czy noc...
  for pora in [Pora.DZIEN, Pora.NOC]:
    # ... oraz dla każdej postaci, czy mówi prawdę (zapalony bit),
    # lub czy kłamie (zgaszony bit).
    for maska in range(1<<N):
      # Wektor mozliwosci okresla wszystkie rasy, jakie moze miec dana 
      # postac.
      mozliwosci = [0 for i in range(N)]
      for i in range(N):
        # Poczatkowo ustawiamy możliwe rasy, w zależności od tego
        # czy mówi prawdę i jaka jest pora dnia.
        if ((1<<i) & maska):
          mozliwosci[i] |= (1<<Rasa.KRASNOLUD.value)
          if pora == Pora.DZIEN: mozliwosci[i] |= (1<<Rasa.ELF.value)
        else:
          mozliwosci[i] |= (1<<Rasa.ORK.value)
          if pora == Pora.NOC: mozliwosci[i] |= (1<<Rasa.ELF.value)
      # Teraz przetwarzamy wszystkie wypowiedzi.
      for wypowiedz in wypowiedzi:
        [autor_wypowiedzi, przedmiot_wypowiedzi, rasa] = \
          [wypowiedz.autor_wypowiedzi, wypowiedz.przedmiot_wypowiedzi, 
           wypowiedz.rasa]
        # Sprawdzamy czy autor wypowiedzi mówi prawdę.
        czy_mowi_prawde = ((1<<autor_wypowiedzi) & maska)
        # I w zależności od tego aktualizujemy mozliwe rasy 
        # postaci, o której jest ta wypowiedź.
        mozliwosci[przedmiot_wypowiedzi] &= \
          (1<<rasa.value) if czy_mowi_prawde else InneRasy(rasa)
      
      # Sprawdzamy teraz, czy sytuacja jest możliwa, tj. czy każda postać
      # ma co najmniej jedną możliwą rasę.
      mozliwe = True
      for i in range(N):
        if mozliwosci[i] == 0: mozliwe = False

      # Jeżeli tak, zapisujemy ten scenariusz.
      if mozliwe: mozliwe_scenariusze.append(mozliwosci)

  cos_wiadomo = False
  # Następnie należy sprawdzić czy wśród wszystkich scneariuszy mamy spójne
  # informacje, tj. czy dla danej postaci we wszystkich możliwych scenariuszach
  # mamy tą samą (unikatową) rasę.
  if len(mozliwe_scenariusze) > 0:
    for i in range(N):
      spojne = True
      for mozliwy_scenariusz in mozliwe_scenariusze:
        if mozliwy_scenariusz[i] != mozliwe_scenariusze[0][i]:
          spojne = False
        
      if spojne and ZliczZapaloneBity(mozliwe_scenariusze[0][i]) == 1:
        print(imiona[i], "jest", NapisZMaski(mozliwe_scenariusze[0][i])+".")
        cos_wiadomo = True

  if not cos_wiadomo: print("Nic nie wiadomo!")


main()